pub struct ModelRef { /* private fields */ }Expand description
Reference to a GGUF model artifact.
The compact form is <org>/<repo>:<quant>, for example
LiquidAI/LFM2.5-350M-GGUF:Q4_K_M. A specific filename can be provided as
<org>/<repo>#<filename>. The filename form is useful for models whose GGUF
filenames cannot be derived from the repository name and quantization suffix.
Implementations
Sourceimpl ModelRef
impl ModelRef
pub fn parse(value: impl AsRef<str>) -> Result<ModelRef, Error>
pub fn default_model() -> ModelRef
pub fn raw(&self) -> &str
pub fn repo_id(&self) -> &str
pub fn quantization(&self) -> Option<&str>
pub fn filename(&self) -> &str
pub fn revision(&self) -> &str
pub fn download_url(&self) -> String